@@ -7,9 +7,13 @@ class index:
         return render.base(view.index(size))
 
 class nearest:
-    def GET(self):
-        return view.nearest()
+    def GET(self, count):
+        return view.nearest(count)
 
 class external_ip:
     def GET(self):
         return view.external_ip()
+
+class wpad:
+    def GET(self):
+        return view.wpad_generator()
